![bpPrior Logo](http://cdn.bitbucket.org/armish/bp_prior/downloads/bpPrior_logo.png)

# BP Prior Information Provider
BioPAX (BP) Prior s a tool for people who work with proteomics data and want to conduct pathway-context aware analysis.
Given a set of annotated protein states,
(such as phosphorylations, active/inactive tags and concentration levels),
this programs creates a map from the input states onto the [Pathway Commons 2](http://www.pathwaycommons.org/pc2/home.html) entities
and finds the minimum distance between them -- the distances are extracted from [BioPAX](htto://www.biopax.org) graphs. 
The ouput, so called `prior information network`, is a tab-limited file in Simple Interaction Format and it contains:

- Source/target entities
- Directional distance measure between these two entities
- [Pubmed](http://www.pubmed.com) IDs associated with links as external references 
- Reactions and their types included in the path between two entities.

# Source Code / Downloads
The latest source code and the executable of the program can be found at [http://bit.ly/bp_prior](http://bit.ly/bp_prior).

# Compiling from the source code
Check out the latest code:

	hg clone "http://bitbucket.org/armish/bp_prior"

In order to work with the latest stable release, switch to the `stable` branch:

	hg update -C stable

Create a runnable JAR from the sources:
	
	cd bp_prior
	# Compile the code and run tests
	mvn clean install
	# Create a single-jar file in the `target` directory
	mvn assembly:single

# Running the program
The runnable JAR file can be either downloaded from the project's web page
or can be created from the scratch by compiling from the source code (see previous section).
To run the program:

	java -jar bp_prior-x.y.z-single.jar

The command above will list all avaliable options to you.
A sample input file can be found under `src/test/resources`.
So if you have compiled the latest source code,
then this will run on the sample list and will save the results in the file `prior_network.tsv`:

	java -jar target/bp_prior-x.y.z-single.jar \
	     -o prior_network.tsv \
	     src/test/resources/example_gene_list.tsv \
	     src/test/resources/reactome_mtor_pathway.owl

Larger input pathway files can be downloaded from Pathway Commons 2 web site, specifically from <http://www.pathwaycommons.org/pc2/downloads.html>.

Please note that, working with larger pathway graphs (such as the whole Pathway Commons 2 BioPAX file) will require adjusting the memory options within the Java Virtual Machine.
If such is the case, please set `-Xmx` as suggested below:

	java -Xmx3g \ 
	     -jar target/bp_prior-x.y.z-single.jar \
	     -o prior_network.tsv \
	     src/test/resources/example_gene_list.tsv \
	     src/test/resources/reactome_mtor_pathway.owl

## Input File Format
BP Prior accepts a tab-delimited (TSV) file as its input. 
This input file contains annotations that helps finding a specific protein state of interest in the BioPAX-formatted pathway.
The columns of this input file are as follows:

1.	*Entity name*:
	This will be used as an identifier of the node in the final prior network.

2.	*State information*:
	Phosphorlayion status of the entity. 
	Starts with **p** followed by the specific phosphorylation status (e.g. pS307)

3.	*Gene Symbol*:
	HUGO gene symbol of the entity (e.g. AKT1)

4.	*Type* (*c*, *a*, or *i*):
	This helps fine-tuning the mapping.
	*c* stands for *concentration* and is usally useful for whole proteins;
	*a* stands for *active* and refers to the *active* form of the protein;
	*i* stands for *inactive* and refers to the *inactive* form.

All lines starting with a dash (#) are ignored and the third column can contain multiple gene names separated with a pipe character (|).
Here is the content of a sample annotation file: `src/test/resources/example_gene_list.tsv`:

	# NodeName_phosphorylation	State	GeneSymbol      activating/inhibitory/concentration
	AKT		AKT1|AKT2|AKT3	c
	TSC_pT1462	pT1462	TSC2	a
	RPS6KB1_pS371	pS371	RPS6KB1	a
	EIF4B_pS422	pS422	EIF4B	a
	iRPTOR_pS722	pS722	RPTOR	i
	AMPKalpha_pY174	pY174	PRKAA1|PRKAA2	a 

## Output file format
The output file is also a tab-delimited file where the columns are ordered as follows:

1.	Source entity name
2. 	Distance
3.	Target entity name
4.	Resources for the path
5.	Pubmed IDs representing the interactions in the path
6.	Interaction types (BioPAX class names) that make up the path between the entities.

Here is the output you wil get if you run the sample example mentioned above:

	RPS6KB1_pS371   1       EIF4B_pS422     Reactome        PubMed:15314020 BiochemicalReaction;Catalysis
	iRPTOR_pS722    1       RPS6KB1_pS371   Reactome        PubMed:15809305 BiochemicalReaction;Control
	iRPTOR_pS722    2       EIF4B_pS422     Reactome        PubMed:15314020;PubMed:15809305 BiochemicalReaction;Catalysis;Control
	AKT     1       TSC_pT1462      Reactome        PubMed:15314020 BiochemicalReaction;Catalysis

## Command line arguments
TODO

## (Optional) Post-processing the output file
BP Prior, by default, does not filter edges out and includes everything it finds in the output. 
This will, for example, sometimes result in self- or redundant edges and these edges can later be removed by any post-processing tool(s).
The project comes with a sample cleaner, `CleanDistanceNetwork.java`, where the following rules are applied to the network:

- remove self-edges (A -> A)
- remove edges where the target node is a `concentration` node and the link found does not include ComplexAssembly (since the program does not consider transcription reactions in the path)
- if the edge is redundant (two separate links indicating, A -> B), merge their fields

In order to use this cleaner, you can simply run the following command on your output file:

	java -cp target/bp_prior-x.y.z-single.jar \
	     org.mskcc.cbio.piclub.CleanDistanceNetwork \ 
	     src/test/resources/example_gene_list.tsv \
	     prior_network.tsv \ 
	     cleaned_prior_network.tsv 

and the file `cleaned_prior_network.tsv` will be the post-processed result.

# For developers
BP Prior not only provides a command line interface, but also acts a Java Library where developers can use it as part of their software in order to enable arbitrary entities to the their corresponding BioPAX entities in a given BioPAX Model.
BP Prior uses [Paxtools](http://www.biopax.org/paxtools.php) as its core library and it follows Paxtools' conventions. 
Please refer to the Paxtools web-site for more infomation on the library and on how to access to and manipulate the BioPAX models programmatically.

But in short, the following code piece provides an example showing how to get the mappings given an input annotation file and a BioPAX model:

	/* Parses the input annotation file and created the ModelNodes (a.k.a entities)
	List<ModelNode> modelNodes = ModelNodeUtil.parseGeneFile(new FileInputStream(annotationFile));
	Model model = (new SimpleIOHandler()).convertFromOWL(new FileInputStream("model.owl"));

	// This is the main mapping utility
	ModelNodeMapper mapper = new ModelNodeMapper();

	// The following configurations match the ones that the command line interface provides
	mapper.setSiteMismatchTolerance(tolerance);
	mapper.setStrict(strict);

	// Extracts the actual mappings
	Map<ModelNode, Set<SimplePhysicalEntity>> map = mapper.map(model, modelNodes);

## Maven repository/dependency information
In order to add BP Prior as a dependency to your Maven project, first add the followign repository information into your pom file:

	<repositories>
		...
                <repository>
                        <id>piclub</id>
                        <name>pi-club related projects</name>
                        <url>http://arman.aksoy.org/m2repo/</url>
                </repository>
		...
	</repositories>

and then add the dependency as follows:

	<dependencies>
		...
        	<dependency>
            		<groupId>org.mskcc.cbio.piclub</groupId>
            		<artifactId>bp-prior</artifactId>
            		<version>VERSION</version>
        	</dependency>
		...
	</dependencies>

You can see the latest release version from the repository tags link: <http://bitbucket.org/armish/bp_prior#tags>.
If you want to include the latest `SNAPSHOT` in your project, then you can have a look at the pom file for the version information: <http://bitbucket.org/armish/bp_prior/src/tip/pom.xml#cl-9>.

# License
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
