/*
 * Copyright (c) 2012 Memorial-Sloan Kettering Cancer Center.
 *
 * This file is part of BP_Prior.
 *
 * BP_Prior is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * BP_Prior is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with BP_Prior.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.mskcc.cbio.piclub.model;

public class ModelNode {
    private String name;
    private String geneSymbol;
    private String state;
    private Type type;
    private Phosphorylation phosphorylation;

    public ModelNode(String name, String state, String geneSymbol, Type type) {
        this.name = name;
        this.state = state;
        this.geneSymbol = geneSymbol;
        this.type = type;

        parsePhosphorylation();
    }

    private void parsePhosphorylation() {
        // Default
        Phosphorylation phosphorylation = Phosphorylation.NONE;

        String value = getState();
        if(value != null && !value.isEmpty()) {
            String residueAbbr = value.substring(1, 2);
            Integer site = Integer.parseInt(value.substring(2, value.length()));

            for(Phosphorylation.Residue aResidue: Phosphorylation.Residue.values()) {
                if(aResidue.getAbbr().compareToIgnoreCase(residueAbbr) == 0) {
                    phosphorylation = new Phosphorylation(aResidue, site);
                    break;
                }
            }
        }

        setPhosphorylation(phosphorylation);
    }

    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
        parsePhosphorylation();
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
        parsePhosphorylation();
    }

    public String getGeneSymbol() {
        return geneSymbol;
    }

    public void setGeneSymbol(String geneSymbol) {
        this.geneSymbol = geneSymbol;
    }

    public Type getType() {
        return type;
    }

    public void setType(Type type) {
        this.type = type;
    }

    public Phosphorylation getPhosphorylation() {
        return phosphorylation;
    }

    public void setPhosphorylation(Phosphorylation phosphorylation) {
        this.phosphorylation = phosphorylation;
    }

    public String toString() {
        return getName();
    }

    public enum Type {
        ACTIVATED("a", "activated"),
        INHIBITED("i", "inhibited"),
        CONCENTRATION("c", "concentration"),
        UNKNOWN("?", "unknown");

        private String abbr;
        private String tag;

        Type(String abbr, String tag) {
            this.abbr = abbr;
            this.tag = tag;
        }

        public String getAbbr() {
            return abbr;
        }

        public String getTag() {
            return tag;
        }

        public String toString() {
            return getTag();
        }
    }

}
