/*
 * Copyright (c) 2012 Memorial-Sloan Kettering Cancer Center.
 *
 * This file is part of BP_Prior.
 *
 * BP_Prior is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * BP_Prior is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with BP_Prior.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.mskcc.cbio.piclub.model;

public class Phosphorylation {
    public static Phosphorylation NONE = new Phosphorylation(Residue.UNKNOWN, 0);

    private Residue residue;
    private Integer site = 0;

    public Phosphorylation(Residue residue, Integer site) {
        this.residue = residue;
        this.site = site;
    }

    public Residue getResidue() {
        return residue;
    }

    public void setResidue(Residue residue) {
        this.residue = residue;
    }

    public Integer getSite() {
        return site;
    }

    public void setSite(Integer site) {
        this.site = site;
    }

    public String toString() {
        return residue.getAbbr() + getSite();
    }

    public boolean isNone() {
        return this.toString().compareTo(NONE.toString()) == 0;
    }

    public enum Residue {
        SERINE("S", "serine"),
        THREONINE("T", "threonine"),
        TYROSINE("Y", "tyrosine"),
        UNKNOWN("N", "unknown");

        private String name;
        private String abbr;

        Residue(String abbr, String name) {
            this.abbr = abbr;
            this.name = name;
        }

        public String getName() {
            return name;
        }

        public void setName(String name) {
            this.name = name;
        }

        public String getAbbr() {
            return abbr;
        }

        public void setAbbr(String abbr) {
            this.abbr = abbr;
        }
    }
}
