/*
 * Copyright (c) 2012 Memorial-Sloan Kettering Cancer Center.
 *
 * This file is part of BP_Prior.
 *
 * BP_Prior is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * BP_Prior is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with BP_Prior.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.mskcc.cbio.piclub.util;

import org.biopax.paxtools.model.level3.*;
import org.mskcc.cbio.piclub.model.Distance;

import java.util.HashSet;
import java.util.Set;

public class DistanceUtil {

    public static String extractPublications(Distance distance) {
        String publications = "";
        Set<String> pubset = new HashSet<String>();

        for(Interaction interaction: distance.getModel().getObjects(Interaction.class)) {
            for(Xref xref: interaction.getXref()) {
                if(xref instanceof PublicationXref)
                    pubset.add(xref.getDb() + ":" + xref.getId());
            }
        }

        for(String pub: pubset)
            publications += pub + ";";

        if(publications.length() > 0) {
            publications = publications.substring(0, publications.length()-1);
        }

        return publications;
    }

    public static String extractResources(Distance distance) {
        String resources = "";
        Set<String> srcSet = new HashSet<String>();

        for(Interaction interaction: distance.getModel().getObjects(Interaction.class)) {
            for(Provenance provenance: interaction.getDataSource()) {
                String standardName = provenance.getStandardName();
                if(standardName != null)
                    srcSet.add(standardName);
            }
        }

        for(String src: srcSet)
            resources += src + ";";

        if(resources.length() > 0) {
            resources = resources.substring(0, resources.length()-1);
        }

        return resources;
    }

    public static String extractTypes(Distance distance) {
        HashSet<String> interactionSet = new HashSet<String>();

        for(Interaction interaction: distance.getModel().getObjects(Interaction.class)) {
            interactionSet.add(interaction.getModelInterface().getSimpleName());
        }

        if(interactionSet.isEmpty() && !distance.getModel().getObjects(Complex.class).isEmpty()) {
            interactionSet.add(Complex.class.getSimpleName());
        }

        String interactions = "";

        for(String interaction: interactionSet)
            interactions += interaction + ";";

        if(interactions.length() > 0) {
            interactions = interactions.substring(0, interactions.length()-1);
        }

        return interactions;
    }
}
