/*
 * Copyright (c) 2012 Memorial-Sloan Kettering Cancer Center.
 *
 * This file is part of BP_Prior.
 *
 * BP_Prior is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * BP_Prior is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with BP_Prior.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.mskcc.cbio.piclub.util;

import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map;
import java.util.Scanner;
import java.util.Set;

public class HGNCUtil {
    private static HGNCUtil hgncUtil = null;
    private Map<String, String> symbolToID = new HashMap<String, String>();

    private HGNCUtil() {
        InputStream hgncFile = getClass().getClassLoader().getResourceAsStream("hgnc.tsv");
        Scanner scanner = new Scanner(hgncFile);

        while(scanner.hasNextLine()) {
            String line = scanner.nextLine().trim();
            if(line.startsWith("#")) // Skip commented lines
                continue;

            if(line.length() == 0)
                break;

            String[] tokens = line.split("\t");
            assert tokens.length <= 3;

            String geneIDString = tokens[0].trim();
            String[] idTokens = geneIDString.split(":");
            assert idTokens.length == 2;

            String id = idTokens[1].trim();
            String symbol = tokens[1].trim();

            symbolToID.put(symbol, id);
        }

        scanner.close();
        try {
            hgncFile.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static HGNCUtil getInstance() {
        if(hgncUtil == null)
            hgncUtil = new HGNCUtil();

        return hgncUtil;
    }

    public String getID(String symbol) {
        return symbolToID.get(symbol);
    }

    public Set<String> getAllSymbols() {
        return symbolToID.keySet();
    }
}
