/*
 * Copyright (c) 2012 Memorial-Sloan Kettering Cancer Center.
 *
 * This file is part of BP_Prior.
 *
 * BP_Prior is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * BP_Prior is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with BP_Prior.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.mskcc.cbio.piclub.util;

import org.mskcc.cbio.piclub.model.ModelNode;

import java.io.InputStream;
import java.util.*;

public class ModelNodeUtil {
    public static List<ModelNode> parseGeneFile(InputStream inputStream) throws Exception {
        ArrayList<ModelNode> modelNodes = new ArrayList<ModelNode>();

        Scanner scanner = new Scanner(inputStream);
        int lineNo = 0;
        while(scanner.hasNextLine()) {
            lineNo++;
            String line = scanner.nextLine();
            // Skip comments
            if(line.startsWith("#"))
                continue;

            if(!line.isEmpty()) {
                String values[] = line.split("\t");
                assert(values.length == 4);
                if(values.length < 4) {
                    throw new Exception("There was a problem with parsing the input file. Line #"
                            + lineNo + " seems to be mis-formatted?");
                }
                String typeStr = values[3].trim();
                ModelNode.Type type = ModelNode.Type.UNKNOWN;

                for(ModelNode.Type aType: ModelNode.Type.values()) {
                    if(typeStr.compareToIgnoreCase(aType.getAbbr()) == 0) {
                        type = aType;
                        break;
                    }
                }

                for(String symbol: values[2].split("\\|"))
                    modelNodes.add(new ModelNode(values[0].trim(), values[1].trim(), symbol.trim(), type));
            }
        }
        scanner.close();

        return modelNodes;
    }

    public static Set<String> extractGeneSymbols(Collection<ModelNode> modelNodes) {
        HashSet<String> symbols = new HashSet<String>();

        for(ModelNode modelNode : modelNodes) {
            symbols.add(modelNode.getGeneSymbol());
        }

        return symbols;
    }

    public static Set<String> extractNodeNames(Collection<ModelNode> modelNodes) {
        HashSet<String> symbols = new HashSet<String>();

        for(ModelNode modelNode : modelNodes) {
            symbols.add(modelNode.getName());
        }

        return symbols;
    }

}
