/*
 * Copyright (c) 2012 Memorial-Sloan Kettering Cancer Center.
 *
 * This file is part of BP_Prior.
 *
 * BP_Prior is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * BP_Prior is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with BP_Prior.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.mskcc.cbio.piclub.util;

import org.biopax.paxtools.controller.PropertyEditor;
import org.biopax.paxtools.controller.SimpleEditorMap;
import org.biopax.paxtools.controller.Traverser;
import org.biopax.paxtools.controller.Visitor;
import org.biopax.paxtools.model.BioPAXElement;
import org.biopax.paxtools.model.BioPAXLevel;
import org.biopax.paxtools.model.Model;
import org.biopax.paxtools.model.level3.EntityReference;
import org.biopax.paxtools.model.level3.RelationshipXref;
import org.biopax.paxtools.model.level3.SimplePhysicalEntity;
import org.biopax.paxtools.model.level3.XReferrable;

import java.util.HashSet;
import java.util.Set;

public class RelationshipXrefExtractor implements Visitor {
    private Traverser traverser;
    private Set<RelationshipXref> xrefs;

    public RelationshipXrefExtractor() {
        traverser = new Traverser(SimpleEditorMap.get(BioPAXLevel.L3), this);
    }

    public void visit(BioPAXElement domain, Object range, Model model, PropertyEditor editor) {
        if(range != null && range instanceof BioPAXElement) {
            BioPAXElement bpe = (BioPAXElement) range;

            if(bpe instanceof RelationshipXref)
                xrefs.add((RelationshipXref) bpe);

            traverser.traverse(bpe, model);
        }
    }

    public Set<RelationshipXref> getXrefs(Model model, SimplePhysicalEntity spe) {
        xrefs = new HashSet<RelationshipXref>();
        traverser.traverse(spe, model);
        return xrefs;
    }

    public Set<EntityReference> getERs(RelationshipXref xref) {
        Set<EntityReference> ers = new HashSet<EntityReference>();
        if(xref != null) {
            for (XReferrable referable : xref.getXrefOf()) {
                if(referable instanceof EntityReference)
                    ers.add((EntityReference) referable);
            }
        }

        return ers;
    }
}
