/*
 * Copyright (c) 2012 Memorial-Sloan Kettering Cancer Center.
 *
 * This file is part of BP_Prior.
 *
 * BP_Prior is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * BP_Prior is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with BP_Prior.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.mskcc.cbio.piclub.util;

import org.junit.Test;
import org.mskcc.cbio.piclub.model.ModelNode;
import org.mskcc.cbio.piclub.model.Phosphorylation;

import java.io.InputStream;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.assertTrue;

public class ModelNodeUtilTest {
    @Test
    public void parseFileTest() throws Exception {
        InputStream fileStream = this.getClass().getClassLoader().getResourceAsStream("example_gene_list.tsv");
        List<ModelNode> modelNodes = ModelNodeUtil.parseGeneFile(fileStream);

        // AKT with 3 symbols adds two extra and AMPK with 2 symbols adds one
        assertEquals(9, modelNodes.size());
        Set<String> symbols = ModelNodeUtil.extractGeneSymbols(modelNodes);
        assertEquals(9, symbols.size());

        Set<String> nodenames = ModelNodeUtil.extractNodeNames(modelNodes);
        assertEquals(6, nodenames.size());

        Iterator<ModelNode> iterator = modelNodes.iterator();

        ModelNode modelNode = iterator.next();
        assertEquals("AKT", modelNode.getName());
        assertEquals("AKT1", modelNode.getGeneSymbol());
        assertEquals(ModelNode.Type.CONCENTRATION, modelNode.getType());

        modelNode = iterator.next();
        assertEquals("AKT", modelNode.getName());
        assertEquals("AKT2", modelNode.getGeneSymbol());
        assertEquals(ModelNode.Type.CONCENTRATION, modelNode.getType());

        modelNode = iterator.next();
        assertEquals("AKT", modelNode.getName());
        assertEquals("AKT3", modelNode.getGeneSymbol());
        assertEquals(ModelNode.Type.CONCENTRATION, modelNode.getType());

        modelNode = iterator.next();
        assertEquals("TSC_pT1462", modelNode.getName());
        assertEquals("TSC2", modelNode.getGeneSymbol());
        assertEquals("pT1462", modelNode.getState());
        assertEquals(ModelNode.Type.ACTIVATED, modelNode.getType());
        assertEquals(Phosphorylation.Residue.THREONINE, modelNode.getPhosphorylation().getResidue());
        assertEquals(new Integer(1462), modelNode.getPhosphorylation().getSite());

        modelNode = iterator.next();
        assertEquals("RPS6KB1_pS371", modelNode.getName());
        assertEquals("RPS6KB1", modelNode.getGeneSymbol());
        assertEquals("pS371", modelNode.getState());
        assertEquals(ModelNode.Type.ACTIVATED, modelNode.getType());
        assertEquals(Phosphorylation.Residue.SERINE, modelNode.getPhosphorylation().getResidue());
        assertEquals(new Integer(371), modelNode.getPhosphorylation().getSite());

        modelNode = iterator.next();
        assertEquals("EIF4B_pS422", modelNode.getName());
        assertEquals("EIF4B", modelNode.getGeneSymbol());
        assertEquals("pS422", modelNode.getState());
        assertEquals(ModelNode.Type.ACTIVATED, modelNode.getType());
        assertEquals(Phosphorylation.Residue.SERINE, modelNode.getPhosphorylation().getResidue());
        assertEquals(new Integer(422), modelNode.getPhosphorylation().getSite());

        modelNode = iterator.next();
        assertEquals("iRPTOR_pS722", modelNode.getName());
        assertEquals("RPTOR", modelNode.getGeneSymbol());
        assertEquals("pS722", modelNode.getState());
        assertEquals(ModelNode.Type.INHIBITED, modelNode.getType());
        assertEquals(Phosphorylation.Residue.SERINE, modelNode.getPhosphorylation().getResidue());
        assertEquals(new Integer(722), modelNode.getPhosphorylation().getSite());

        modelNode = iterator.next();
        assertEquals("AMPKalpha_pY174", modelNode.getName());
        assertEquals("PRKAA1", modelNode.getGeneSymbol());
        assertEquals("pY174", modelNode.getState());
        assertEquals(ModelNode.Type.ACTIVATED, modelNode.getType());
        assertEquals(Phosphorylation.Residue.TYROSINE, modelNode.getPhosphorylation().getResidue());
        assertEquals(new Integer(174), modelNode.getPhosphorylation().getSite());

        modelNode = iterator.next();
        assertEquals("AMPKalpha_pY174", modelNode.getName());
        assertEquals("PRKAA2", modelNode.getGeneSymbol());
        assertEquals("pY174", modelNode.getState());
        assertEquals(ModelNode.Type.ACTIVATED, modelNode.getType());
        assertEquals(Phosphorylation.Residue.TYROSINE, modelNode.getPhosphorylation().getResidue());
        assertEquals(new Integer(174), modelNode.getPhosphorylation().getSite());
    }
}
